==> haskell-easytest-0.2.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-easytest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: easytest
version: 0.2.1
id: easytest-0.2.1-Fvr3pELpRTdDli5viSGCl3
key: easytest-0.2.1-Fvr3pELpRTdDli5viSGCl3
license: MIT
copyright: Copyright (C) 2017-2018 Joel Burget, Copyright (C) 2016 Paul Chiusano and contributors
maintainer: Joel Burget <joelburget@gmail.com>
author: Joel Burget, Paul Chiusano
stability: provisional
homepage: https://github.com/joelburget/easytest
synopsis: Simple, expressive testing library
description:
    EasyTest is a simple testing toolkit, meant to replace most uses of QuickCheck, SmallCheck, HUnit, and frameworks like Tasty, etc. Here'\''s an example usage:
    .
    > module Main where
    >
    > import EasyTest
    > import Control.Applicative
    > import Control.Monad
    >
    > suite :: Test ()
    > suite = tests
    >   [ scope "addition.ex1" $ expect (1 + 1 == 2)
    >   , scope "addition.ex2" $ expect (2 + 3 == 5)
    >   , scope "list.reversal" . fork $ do
    >       -- generate lists from size 0 to 10, of Ints in (0,43)
    >       -- shorthand: listsOf [0..10] (int'\'' 0 43)
    >       ns <- [0..10] `forM` \n -> replicateM n (int'\'' 0 43)
    >       ns `forM_` \ns -> expect (reverse (reverse ns) == ns)
    >   -- equivalent to `scope "addition.ex3"`
    >   , scope "addition" . scope "ex3" $ expect (3 + 3 == 6)
    >   , scope "always passes" $ do
    >       note "I'\''m running this test, even though it always passes!"
    >       ok -- like `pure ()`, but records a success result
    >   , scope "failing test" $ crash "oh noes!!" ]
    >
    > -- NB: `run suite` would run all tests, but we only run
    > -- tests whose scopes are prefixed by "addition"
    > main = runOnly "addition" suite
    .
    This generates the output:
    .
    > Randomness seed for this run is 5104092164859451056
    > Raw test output to follow ...
    > ------------------------------------------------------------
    > OK addition.ex1
    > OK addition.ex2
    > OK addition.ex3
    > ------------------------------------------------------------
    > ✅  3 tests passed, no failures! 👍 🎉
    The idea here is to write tests with ordinary Haskell code, with control flow explicit and under programmer control.
category: Testing
abi: e92565f6e1c46e8e454cc613e93ff644
exposed: True
exposed-modules:
    EasyTest EasyTest.Internal
hidden-modules: EasyTest.Generators EasyTest.Porcelain
import-dirs: /usr/lib/ghc-8.6.5/site-local/easytest-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/easytest-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/easytest-0.2.1
hs-libraries: HSeasytest-0.2.1-Fvr3pELpRTdDli5viSGCl3
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ containers-0.6.0.1
    mtl-2.2.2 random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-easytest/html/easytest.haddock
haddock-html: /usr/share/doc/haskell-easytest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-easytest-0.2.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-easytest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: easytest
version: 0.2.1
id: easytest-0.2.1-3BFqxjiTZ2Q3sAJGnfHhsv
key: easytest-0.2.1-3BFqxjiTZ2Q3sAJGnfHhsv
license: MIT
copyright: Copyright (C) 2017-2018 Joel Burget, Copyright (C) 2016 Paul Chiusano and contributors
maintainer: Joel Burget <joelburget@gmail.com>
author: Joel Burget, Paul Chiusano
stability: provisional
homepage: https://github.com/joelburget/easytest
synopsis: Simple, expressive testing library
description:
    EasyTest is a simple testing toolkit, meant to replace most uses of QuickCheck, SmallCheck, HUnit, and frameworks like Tasty, etc. Here'\''s an example usage:
    .
    > module Main where
    >
    > import EasyTest
    > import Control.Applicative
    > import Control.Monad
    >
    > suite :: Test ()
    > suite = tests
    >   [ scope "addition.ex1" $ expect (1 + 1 == 2)
    >   , scope "addition.ex2" $ expect (2 + 3 == 5)
    >   , scope "list.reversal" . fork $ do
    >       -- generate lists from size 0 to 10, of Ints in (0,43)
    >       -- shorthand: listsOf [0..10] (int'\'' 0 43)
    >       ns <- [0..10] `forM` \n -> replicateM n (int'\'' 0 43)
    >       ns `forM_` \ns -> expect (reverse (reverse ns) == ns)
    >   -- equivalent to `scope "addition.ex3"`
    >   , scope "addition" . scope "ex3" $ expect (3 + 3 == 6)
    >   , scope "always passes" $ do
    >       note "I'\''m running this test, even though it always passes!"
    >       ok -- like `pure ()`, but records a success result
    >   , scope "failing test" $ crash "oh noes!!" ]
    >
    > -- NB: `run suite` would run all tests, but we only run
    > -- tests whose scopes are prefixed by "addition"
    > main = runOnly "addition" suite
    .
    This generates the output:
    .
    > Randomness seed for this run is 5104092164859451056
    > Raw test output to follow ...
    > ------------------------------------------------------------
    > OK addition.ex1
    > OK addition.ex2
    > OK addition.ex3
    > ------------------------------------------------------------
    > ✅  3 tests passed, no failures! 👍 🎉
    The idea here is to write tests with ordinary Haskell code, with control flow explicit and under programmer control.
category: Testing
abi: 7a62b4762e36918388c4873da3a1e24a
exposed: True
exposed-modules:
    EasyTest EasyTest.Internal
hidden-modules: EasyTest.Generators EasyTest.Porcelain
import-dirs: /usr/lib/ghc-8.6.5/site-local/easytest-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/easytest-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/easytest-0.2.1
hs-libraries: HSeasytest-0.2.1-3BFqxjiTZ2Q3sAJGnfHhsv
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    call-stack-0.2.0-7kE9ck8b3cWExm7jAiSNAI containers-0.6.0.1
    mtl-2.2.2 random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-easytest/html/easytest.haddock
haddock-html: /usr/share/doc/haskell-easytest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
